[Pkg-mozext-commits] [tabmixplus] 95/107: When 'browser.newtab.url' or 'extensions.tabmix.replaceLastTabWith.newtab.url' value is empty string show 'about:blank' in the corresponding text box in the option windows

David Prévot taffit at moszumanska.debian.org
Tue Dec 29 19:02:55 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository tabmixplus.

commit bc28b82bf56a5d83717b8f6fd875c86a1a5add35
Author: onemen <tabmix.onemen at gmail.com>
Date:   Thu Dec 10 22:58:50 2015 +0200

    When 'browser.newtab.url' or 'extensions.tabmix.replaceLastTabWith.newtab.url' value is empty string show 'about:blank' in the corresponding text box in the option windows
---
 chrome/content/preferences/events.js | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/chrome/content/preferences/events.js b/chrome/content/preferences/events.js
index 92d2afe..a5d8a21 100644
--- a/chrome/content/preferences/events.js
+++ b/chrome/content/preferences/events.js
@@ -87,13 +87,13 @@ var gEventsPane = {
     let value = preference.value;
     if (value && value.toLowerCase() == TabmixSvc.aboutNewtab)
       return "";
-    return this.syncToNewTabUrlPref(value);
+    return this.syncToNewTabUrlPref(value, TabmixSvc.aboutBlank);
   },
 
-  syncToNewTabUrlPref: function(value) {
-    // If the value is "", use about:newtab.
+  syncToNewTabUrlPref: function(value, def = TabmixSvc.aboutNewtab) {
+    // If the value is "", use about:newtab or about:blank.
     if (value === "") {
-      return TabmixSvc.aboutNewtab;
+      return def;
     }
 
     // Otherwise, use the actual textbox value.

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/tabmixplus.git



More information about the Pkg-mozext-commits mailing list